#[repr(C)]
pub struct XSizeHints {Show fields
pub flags: c_long,
pub x: c_int,
pub y: c_int,
pub width: c_int,
pub height: c_int,
pub min_width: c_int,
pub min_height: c_int,
pub max_width: c_int,
pub max_height: c_int,
pub width_inc: c_int,
pub height_inc: c_int,
pub min_aspect: AspectRatio,
pub max_aspect: AspectRatio,
pub base_width: c_int,
pub base_height: c_int,
pub win_gravity: c_int,
}
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.